[![image](https://img.shields.io/pypi/v/mf-prior-bench.svg)](https://pypi.python.org/pypi/mf-prior-bench)
[![image](https://img.shields.io/pypi/l/mf-prior-bench.svg)](https://pypi.python.org/pypi/mf-prior-bench)
[![image](https://img.shields.io/pypi/pyversions/mf-prior-bench.svg)](https://pypi.python.org/pypi/mf-prior-bench)
[![Actions](https://github.com/automl/mf-prior-bench/actions/workflows/pytest.yml/badge.svg)](https://github.com/automl/mf-prior-bench/actions)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)

# mf-prior-bench
Please check out the docs [automl.github.io/mf-prior-bench](https://automl.github.io/mf-prior-bench/latest/)!
